API docs for “spamfighter.rules.frequency”

# Module s.r.frequency

Part of spamfighter.rules View Source

Набор правил проверки текста сообщений на частоту

Function | calculateMD5 | Вычисление md5 от строки в любой кодировки.
Function | clearMessage | Функция удаления из текста сообщения всех символов, кроме букв.
Function | messageFrequencyCheck | Правило проверки сообщение на частоту повторения.
Function | userFrequencyCheck | Правило проверки сообщения на частоту отправки указанным пользователем.

def calculateMD5(string): (source)
Вычисление md5 от строки в любой кодировки.

Parameters | string | строка для которой надо посчитать md5 (type: `unicode` )
Returns | значение md5 (type: `str` )

def clearMessage(text): (source)
Функция удаления из текста сообщения всех символов, кроме букв.

Parameters | text | текст сообщения, который мы будем анализировать (type: `unicode` )
Returns | значение md5 (type: `unicode` )

def messageFrequencyCheck(domain, message, attribute='text', storage='storage', timeout=300, count=3, minLength=10): (source)
Правило проверки сообщение на частоту повторения.

Parameters | domain | домен, относительно которого идёт анализ (type: `IDomain` )
| message | сообщение (type: `spamfighter.interfaces.IMessage` )
| attribute | имя атрибута сообщения, содержащего поле для проверки (type: `str` )
| storage | имя атрибута домена, содержащего хранилище (type: `str` )
| timeout | время не повторения сообщения, секунды (type: `int` )
| count | максимально допустимое количество сообщение в указанный период времени (type: `int` )
| minLength | минимальная длина сообщения для анализа (type: `int` )

def userFrequencyCheck(domain, message, attribute='from', storage='storage', timeout=300, count=3): (source)
Правило проверки сообщения на частоту отправки указанным пользователем.

Parameters | domain | домен, относительно которого идёт анализ (type: `IDomain` )
| message | сообщение (type: `spamfighter.interfaces.IMessage` )
| attribute | имя атрибута сообщения, содержащее идентификатор пользователя отославшего его (type: `int` )
| storage | имя атрибута домена, содержащего хранилище (type: `str` )
| timeout | время в течении которого пользователь может отправлять указанное количество сообщений (type: `int` )
| count | максимально допустимое количество сообщение в указанный период времени (type: `int` )